require_relative "base_helper"

describe Toolchain::Attributes, "Attribute" do

  let(:model) { ModelData.new }

  it "should be nil by default" do
    model.string.should == nil
  end

  it "should be empty by default" do
    model.string_default.should == ""
  end

  it "should set a new String" do
    expect { model.string = "Example" }.
      to change { model.string }.from(nil).to("Example")
  end

  it "should set to nil, resulting in default" do
    model.string_default = "Example"
    expect { model.string_default = nil }.
      to change { model.string_default }.from("Example").to("")
  end

  it "should instance-variable cache the result" do
    model.time_default.should == model.time_default
  end

  it "requires the type to match the configured type" do
    expect { model.string = 0 }.to raise_error(
      Toolchain::Attributes::Errors::TypeMismatch,
      "ModelData#string expected String type, but received Fixnum (0).")
  end

  it "should not allow defaults of other data-type" do
    expect {
      class InvalidModelData
        include Toolchain::Attributes
        attribute :string, String, 0
      end
    }.to raise_error(
      Toolchain::Attributes::Errors::TypeMismatch,
      "expected InvalidModelData#string to have default value "+
      "of String type, but received Fixnum (0).")
  end
end
