require_relative "base_helper"

describe Toolchain::Validations, "Delegation" do

  module PersonAttributes
    attr_accessor :name, :email, :terms, :new

    def keys
      [:name, :email, :terms, :new]
    end

    def attributes
      { name: name, email: email, terms: terms, new: new }
    end

    def attributes=(attrs)
      attrs.each do |key, value|
        send("#{key}=", value) if keys.include?(key)
      end
    end
  end

  class BasePersonValidator
    include PersonAttributes
    include Toolchain::Validations
    include Toolchain::Validations::Delegation
    validates :name, presence: true
    validates :email, email: true
  end

  class NewPersonValidator < BasePersonValidator
    validates :terms, acceptance: true
  end

  class ExistingPersonValidator < BasePersonValidator
  end

  class PersonDelegatorValidation
    include PersonAttributes
    include Toolchain::Validations::Delegator

    validate_with do |i|
      if i.new
        NewPersonValidator
      else
        ExistingPersonValidator
      end
    end
  end

  it "should validate name, email, terms" do
    person = PersonDelegatorValidation.new
    person.new = true
    person.should_not be_valid
    person.errors.to_hash.should == {
      name: ["can't be blank"],
      email: ["is invalid"],
      terms: ["must be accepted"]
    }
  end

  it "should validate name, email" do
    person = PersonDelegatorValidation.new
    person.should_not be_valid
    person.errors.to_hash.should == {
      name: ["can't be blank"],
      email: ["is invalid"]
    }
  end
end
