require_relative "base_helper"

describe Toolchain::Validations, "Nested Validation" do

  class UserNestedValidation
    include Toolchain::Validations
    attr_accessor :config
    validates :config, :name, presence: true
    validates :config, :email, email: true
  end

  let(:user) { UserNestedValidation.new }

  it "should be valid" do
    user.config = {
      name: "Example",
      email: "example@machinery.io"
    }
    user.should be_valid
  end

  it "is invalid if nil" do
    user.should_not be_valid
    user.errors[:config][:name].should == ["can't be blank"]
    user.errors[:config][:email].should == ["is invalid"]
  end

  class UserDeeplyNestedValidation
    include Toolchain::Validations
    attr_accessor :config
    validates :config, :deep, :name, presence: true
    validates :config, :deep, :email, email: true
  end

  it "should be valid" do
    user = UserDeeplyNestedValidation.new
    user.config = {
      deep: {
        name: "Example",
        email: "example@machinery.io"
      }
    }
    user.should be_valid
  end

  it "is invalid if nil" do
    user = UserDeeplyNestedValidation.new
    user.config = {}
    user.should_not be_valid
    user.errors[:config][:deep][:name].should == ["can't be blank"]
  end

  class UserCustomNestedValidation
    include Toolchain::Validations
    attr_accessor :config
    validate :name_validation

    def name_validation
      errors.add(:config, :name, "custom validation error")
    end
  end

  it "should be invalid" do
    user = UserCustomNestedValidation.new
    user.should_not be_valid
    user.errors.should == { config: { name: ["custom validation error"] } }
  end
end
