require_relative "../base_helper"

describe Toolchain::Validations::Validators::Confirmation do

  class UserConfirmation
    include Toolchain::Validations
    attr_accessor :password
    attr_accessor :password_confirmation
    validates :password, confirmation: true
  end

  it "should be valid" do
    user = UserConfirmation.new
    user.password = "hackery"
    user.password_confirmation = "hackery"
    user.should be_valid
  end

  it "should be invalid if nil" do
    user = UserConfirmation.new
    user.password = nil
    user.password_confirmation = nil
    user.should_not be_valid
    user.errors[:password].should == ["doesn't match confirmation"]
  end

  it "should be invalid if it doesn't match" do
    user = UserConfirmation.new
    user.password = "hackery"
    user.password_confirmation = "h4ckery"
    user.should_not be_valid
    user.errors[:password].should == ["doesn't match confirmation"]
  end

  class UserNestedConfirmation
    include Toolchain::Validations
    attr_accessor :config
    validates :config, :password, confirmation: true
  end

  it "should be valid" do
    user = UserNestedConfirmation.new
    user.config = {
      password: "hackery",
      password_confirmation: "hackery"
    }
    user.should be_valid
  end

  it "should be invalid if nil" do
    user = UserNestedConfirmation.new
    user.config = {}
    user.should_not be_valid
    user.errors[:config][:password].should == ["doesn't match confirmation"]
  end

  it "should be invalid if nil" do
    user = UserNestedConfirmation.new
    user.config = nil
    user.should_not be_valid
    user.errors[:config][:password].should == ["doesn't match confirmation"]
  end

  it "should be invalid if it doesn't match" do
    user = UserNestedConfirmation.new
    user.config = {
      password: "hackery",
      password_confirmation: "h4ckery"
    }
    user.should_not be_valid
    user.errors[:config][:password].should == ["doesn't match confirmation"]
  end

  class UserConfirmationMessage
    include Toolchain::Validations
    attr_accessor :password
    attr_accessor :password_confirmation
    validates :password, confirmation: { message: "isn't the same as confirmation" }
  end

  it "should be invalid" do
    user = UserConfirmationMessage.new
    user.should_not be_valid
    user.errors[:password].should == ["isn't the same as confirmation"]
  end
end
