require_relative "../base_helper"

describe Toolchain::Validations::Validators::Email do

  class UserEmail
    include Toolchain::Validations
    attr_accessor :email
    validates :email, email: true
  end

  it "should be valid" do
    user = UserEmail.new
    user.email = "michael@machinery.io"
    user.should be_valid
  end

  it "is invalid if nil" do
    user = UserEmail.new
    user.should_not be_valid
    user.errors[:email].should == ["is invalid"]
  end

  it "is invalid if invalid format" do
    user = UserEmail.new
    user.email = "michael.machinery.io"
    user.should_not be_valid
    user.errors[:email].should == ["is invalid"]
  end

  class UserEmailMessage
    include Toolchain::Validations
    attr_accessor :email
    validates :email, email: { message: "incorrect format" }
  end

  it "should have a custom error message" do
    user = UserEmailMessage.new
    user.should_not be_valid
    user.errors[:email].should == ["incorrect format"]
  end
end
