require_relative "../base_helper"

describe Toolchain::Validations::Validators::Exclusion do

  class UserExclusion
    include Toolchain::Validations
    attr_accessor :color
    validates :color, exclusion: { in: ["red", "green", "blue"] }
  end

  it "should be invalid if 'red'" do
    user = UserExclusion.new
    user.color = "red"
    user.should_not be_valid
    user.errors[:color].should == ["is invalid"]
  end

  it "should be invalid if 'green'" do
    user = UserExclusion.new
    user.color = "green"
    user.should_not be_valid
    user.errors[:color].should == ["is invalid"]
  end

  it "should be invalid if 'blue'" do
    user = UserExclusion.new
    user.color = "blue"
    user.should_not be_valid
    user.errors[:color].should == ["is invalid"]
  end

  it "should be valid if 'yellow'" do
    user = UserExclusion.new
    user.color = "yellow"
    user.should be_valid
  end

  class UserExclusionMessage
    include Toolchain::Validations
    attr_accessor :color
    validates :color, exclusion: {
      in: ["red", "green", "blue"],
      message: "don't pick red, green or blue"
    }
  end

  it "should be invalid" do
    user = UserExclusionMessage.new
    user.color = "red"
    user.should_not be_valid
    user.errors[:color].should == ["don't pick red, green or blue"]
  end
end
