require_relative "../base_helper"

describe Toolchain::Validations::Validators::Format do

  class UserFormat
    include Toolchain::Validations
    attr_accessor :cc
    validates :cc, format: { with: /^\d{4}-\d{4}-\d{4}-\d{4}$/ }
  end

  it "should be valid" do
    user = UserFormat.new
    user.cc = "1234-5678-1234-5678"
    user.should be_valid
  end

  it "is invalid if nil" do
    user = UserFormat.new
    user.should_not be_valid
    user.errors[:cc].should == ["is invalid"]
  end

  it "is invalid if format doesn't match" do
    user = UserFormat.new
    user.cc = "12-34-56-78"
    user.should_not be_valid
    user.errors[:cc].should == ["is invalid"]
  end

  class UserFormatMessage
    include Toolchain::Validations
    attr_accessor :cc
    validates :cc, format: {
      with: /^\d{4}-\d{4}-\d{4}-\d{4}$/,
      message: "not a cc"
    }
  end

  it "should have a custom error message" do
    user = UserFormatMessage.new
    user.should_not be_valid
    user.errors[:cc].should == ["not a cc"]
  end
end
