require_relative "../base_helper"

describe Toolchain::Validations::Validators::Inclusion do

  class UserInclusion
    include Toolchain::Validations
    attr_accessor :color
    validates :color, inclusion: { in: ["red", "green", "blue"] }
  end

  it "should be valid if 'red'" do
    user = UserInclusion.new
    user.color = "red"
    user.should be_valid
  end

  it "should be valid if 'green'" do
    user = UserInclusion.new
    user.color = "green"
    user.should be_valid
  end

  it "should be valid if 'blue'" do
    user = UserInclusion.new
    user.color = "blue"
    user.should be_valid
  end

  it "should be invalid if 'yellow'" do
    user = UserInclusion.new
    user.color = "yellow"
    user.should_not be_valid
    user.errors[:color].should == ["is invalid"]
  end

  class UserInclusionMessage
    include Toolchain::Validations
    attr_accessor :color
    validates :color, inclusion: {
      in: ["red", "green", "blue"],
      message: "only pick red, green or blue"
    }
  end

  it "should be invalid" do
    user = UserInclusionMessage.new
    user.should_not be_valid
    user.errors[:color].should == ["only pick red, green or blue"]
  end
end
