require_relative "../base_helper"

describe Toolchain::Validations::Validators::Length do

  class UserLength
    include Toolchain::Validations
    attr_accessor :password
    validates :password, length: { between: 5..100 }
  end

  it "should be valid" do
    user = UserLength.new
    user.password = "mypassword"
    user.should be_valid
  end

  it "should be too short" do
    user = UserLength.new
    user.password = "pass"
    user.should_not be_valid
    user.errors[:password].should == ["is invalid"]
  end

  it "should be too long" do
    user = UserLength.new
    user.password = "mypassword" * 11
    user.should_not be_valid
    user.errors[:password].should == ["is invalid"]
  end

  class UserLengthGreaterThanAndLessThan
    include Toolchain::Validations
    attr_accessor :password
    validates :password, length: {
      greater_than: 5, less_than: 100
    }
  end

  it "should be too short" do
    user = UserLengthGreaterThanAndLessThan.new
    user.password = "pass"
    user.should_not be_valid
    user.errors[:password].should == ["is invalid"]
  end

  it "should be too long" do
    user = UserLengthGreaterThanAndLessThan.new
    user.password = "mypassword" * 10
    user.should_not be_valid
    user.errors[:password].should == ["is invalid"]
  end

  class UserLengthGreaterThan
    include Toolchain::Validations
    attr_accessor :password
    validates :password, length: { greater_than: 5 }
  end

  it "should be too short" do
    user = UserLengthGreaterThan.new
    user.password = "pass"
    user.should_not be_valid
    user.errors[:password].should == ["is invalid"]
  end

  class UserLengthLessThan
    include Toolchain::Validations
    attr_accessor :password
    validates :password, length: { less_than: 100 }
  end

  it "should be too short" do
    user = UserLengthLessThan.new
    user.password = "mypassword" * 10
    user.should_not be_valid
    user.errors[:password].should == ["is invalid"]
  end

  class UserLengthOfDigit
    include Toolchain::Validations
    attr_accessor :number
    validates :number, length: { between: 5..10 }
  end

  it "should be invalid" do
    user = UserLengthOfDigit.new
    user.number = 1
    user.should_not be_valid
    user.errors[:number].should == ["is invalid"]
  end

  it "should be valid" do
    user = UserLengthOfDigit.new
    user.number = 7
    user.should be_valid
  end

  it "should be invalid" do
    user = UserLengthOfDigit.new
    user.number = "1"
    user.should_not be_valid
    user.errors[:number].should == ["is invalid"]
  end

  it "should be valid" do
    user = UserLengthOfDigit.new
    user.number = "7"
    user.should be_valid
  end

  it "should be invalid" do
    user = UserLengthOfDigit.new
    user.number = "1.123"
    user.should_not be_valid
    user.errors[:number].should == ["is invalid"]
  end

  it "should be valid" do
    user = UserLengthOfDigit.new
    user.number = "7.512"
    user.should be_valid
  end

  class UserLengthNoMatcher
    include Toolchain::Validations
    attr_accessor :number
    validates :number, length: {}
  end

  it "should be invalid" do
    user = UserLengthNoMatcher.new
    user.should_not be_valid
  end
end
